pub struct SlotToggle {
pub slot_added: u64,
pub slot_removed: u64,
pub reserved: [u8; 32],
}Fields
slot_added: u64slot_removed: u64reserved: [u8; 32]Trait Implementations
Sourceimpl BorshDeserialize for SlotToggle
impl BorshDeserialize for SlotToggle
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SlotToggle
impl BorshSerialize for SlotToggle
Sourceimpl Clone for SlotToggle
impl Clone for SlotToggle
Sourcefn clone(&self) -> SlotToggle
fn clone(&self) -> SlotToggle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SlotToggle
impl Debug for SlotToggle
Sourceimpl PartialEq for SlotToggle
impl PartialEq for SlotToggle
Sourcefn eq(&self, other: &SlotToggle) -> bool
fn eq(&self, other: &SlotToggle) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SlotToggle
impl StructuralPartialEq for SlotToggle